Command Line Interface
======================
stonkgs automatically installs the command :code:`stonkgs`. See
:code:`stonkgs --help` for usage details.

.. click:: stonkgs.cli:main
   :prog: stonkgs
   :show-nested:
